=====
Usage
=====

Enable `cmis storage` in the admin of the drc under `Plugin` `Storage Config`.

After a second reload of the admin dashboard, a new item will appear. `CMIS Configuration`.

In here you can specify the conection to the CMIS server. E.G. Alfresco.

Required are the

- **Client Url**, The location where the cmis config can be downloaded.
- **Client User**, The user created to talk to the cmis server.
- **Client Password**, The password for the user above.

After these fields are set, the DRC can be used as normal.
